import React, { useState } from "react";
import styled from "styled-components";
import useCopying from "./useCopying";

const Container = styled.div`
  position: relative;
  display: inline-flex;
  justify-content: center;
`

const UnderlinedSpan = styled.span`
  border-bottom: 1px dashed #bbb;
`

const ToolTip = styled.span`
  background-color: black;
  color: white;
  text-align: center;
  padding: 2px 8px;
  border-radius: 8px;
  position: absolute;
  z-index: 1;
  top: -115%;
  white-space: nowrap;
  transition: opacity 0.25s;
  opacity: ${({ show }) => show ? 0.75 : 0};
`

export default ({ text }) => {
  const [textareaChild, copyText] = useCopying(text);
  const [hovered, setHovered] = useState(false);
  const [copied, setCopied] = useState(false);

  return (
    <Container>
      <UnderlinedSpan
        onClick={() => {copyText(); setCopied(true)}}
        onMouseOver={() => {setCopied(false); setHovered(true)}}
        onMouseOut={() => setHovered(false)}
      >
        {text}
      </UnderlinedSpan>
      <ToolTip show={hovered}>
        {copied ? "Copied!" : "Click to Copy"}
      </ToolTip>
      {textareaChild}
    </Container>
  )
}
